@@ -5,7 +5,12 @@ def prompt():
     '''
     return raw_input('Was that appropriate? ')
 
-def prompt_again():
+def prompt1():
     ''' Returns response from user.
     '''
     return raw_input('Enter the number respective to download subtitle: ')
+
+def prompt2():
+    ''' Returns response from user.
+    '''
+    return raw_input('Choose the movie from the list. Enter the corresponding number: ')
